Rational polynomial usage (sarpy.processing.rational_polynomial)
================================================================

.. automodule:: sarpy.processing.rational_polynomial
    :members:
    :show-inheritance:
    :inherited-members:
